import { defineLayout } from '@directus/extensions';
import { useCollection, useItems } from '@directus/extensions-sdk';
import { ref, toRefs } from 'vue';
import { useRouter } from 'vue-router';
import LayoutComponent from './layout.vue';

export default defineLayout({
	id: 'tasks',
	name: 'swablab tasks',
	icon: 'task_alt',
	component: LayoutComponent,
	slots: {
		options: () => null,
		sidebar: () => null,
		actions: () => null,
	},
	setup(props) {
		const router = useRouter();
		const { collection, filter, search } = toRefs(props);
		const { info, fields } = useCollection(collection);

		const { items, loading, error } = useItems(collection, {
			sort: ref(['date_due', 'date_created']),
			limit: ref(-1),
			fields: ref(['*', '*.directus_users_id.*']),
			page: ref(null),
			filter,
			search,
		})

		const me = ref('')
		fetch("/users/me").then(x => x.json()).then(x => me.value = x.data.id)

		return {
			info,
			items,
			loading,
			fields,
			error,
			router,
			me,
		}
	},
})
