import { defineOperationApi } from '@directus/extensions-sdk';

type Options = {
	token: string
	instance: string
	flow: string
	debug: boolean
}

type Data = {
	// create and update trigger
	event?: string
	collection?: string

	// create trigger
	key: string

	// update trigger
	keys?: string[]

	// manual trigger
	body?: {
		collection: string
		keys: string[]
	}
}

export default defineOperationApi<Options>({
	id: 'windmill',
	handler: async ({ token, instance, flow, debug }, { data }) => {
		const last = data.$last as Data
		const body = JSON.stringify({
			event: last.event ?? "manual",
			instance: instance,
			collection: last.collection ?? last.body?.collection,
			keys: last.keys ?? last.body?.keys ?? [last.key],
			debug: debug,
		})

		return await fetch(`https://windmill.swablab.de/api/r/${flow}`, {
			method: 'POST',
			headers: {
				"Content-Type": "application/json",
				"Authorization": `Bearer ${token}`
			},
			body
		})
	},
});
